#
# spec file for package python-particle
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global modname particle
%define skip_python2 1
%define skip_python36 1
Name:           python-particle
Version:        0.24.0
Release:        1.1
Summary:        PDG particle data and identification codes
License:        BSD-3-Clause
URL:            https://github.com/scikit-hep/particle
Source0:        https://files.pythonhosted.org/packages/source/p/particle/%{modname}-%{version}.tar.gz
Source1:        python-particle.rpmlintrc
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module toml}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Deprecated
Requires:       python-attrs >= 19.2
Requires:       python-hepunits >= 2.0.0
Recommends:     python-pandas
Recommends:     python-tabulate
BuildArch:      noarch
# SECTION For tests
BuildRequires:  %{python_module Deprecated}
BuildRequires:  %{python_module hepunits}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Particle provides a pythonic interface to the Particle Data Group (PDG)
particle data tables and particle identification codes.

%prep
%setup -q -n %{modname}-%{version}
sed -Ei "1{/^#!\/usr\/bin\/env python/d}" src/particle/__main__.py

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand # Copy missed files
cp -R src/particle/data %{buildroot}%{$python_sitelib}/%{modname}/
cp -R src/particle/lhcb %{buildroot}%{$python_sitelib}/%{modname}/
}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}*-info/

%changelog
* Tue Apr 23 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.24.0:
  * Particle class and submodules: Removed deprecated methods.
  * Data files: Fixed typo in the LaTeX name of Lambda(1405).
  * Miscellaneous: Added support for Python 3.12 and dropped
    support for Python 3.7.
* Tue Dec 12 2023 Dirk Müller <dmueller@suse.com>
- update to 0.23.1:
  * Modernisation of Ruff configuration in pyproject.toml.
  * Updates to pre-commit hooks and CI YAML files.
* Tue Jul 11 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.23.0:
  * Added the 2023 PDG data table file, now default.
  * Version 13 of package CSV data files: Since PDG 2023
    information is now the default.
  * Removed superseded data files from 2018-2020.
* Mon Jul  3 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.22.1:
  * Particle class and submodules: Added support for providing
    spin for SUSY particles, with tests.
  * Tests: Test added for particles that should be assigned None
    masses.
- Add python-particle.rpmlintrc to disable some
  "python-missing-requires" false positives.
- Update deps:
  * Drop BuildRequires: python-importlib-metadata as no longer
    needed for python < 3.9
  * Add Requires: python-Deprecated.
* Thu May  4 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.22.0:
  * Particle class and submodules:
  - Deprecated functions only used to find particles by AmpGen
    style of names.
  - Functionality moved to the DecayLanguage package, the only
    place where it is needed.
  * Data CSV files:
  - Information on nuclei updated based on masses taken from
    package periodictable version 1.6.1.
  - Several Corsika7 IDs corrected.
  * Miscellaneous:
  - Moved to Ruff for configuration.
  * Documentation:
  - Various fixes in docstrings, notably because of particle
    property updates.
  - README: minor updates/fixes.
  * Tests:
  - Doctests run separately in the CI.
  - Updates to pre-commit hooks.
- Drop additional Source tests.tar.xz: tests are now included with
  upstream tarball; drop _service file.
* Tue Jan 24 2023 Matej Cepl <mcepl@suse.com>
- Switch to %%pyproject_wheel/install, there is no need to create
  setup.py manually.
* Mon Jan 23 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.21.1:
  * Particle class and submodules: Better test coverage.
  * PDGID class method and related standalone functions:
  - Minor code simplifications.
  - Significant improvements to test coverage.
  * README: info added on how to create user-defined particles.
- Update tests.tar.xz to tag 0.21.1.
- Create a basic setup.py file to allow building and installation.
- Manually copy missed data files into buildroot.
- Disable python3.6 building, no longer supported by upstream.
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.20.1:
  * Particle class: More tests of PDGID functions for special
    particles.
  * Experiment-specific modules: particle.lhcb simplified.
  * Miscellaneous: Minor cleanup and updates.
  * Tests: Now included in the SDist (MANIFEST.in updated).
* Thu Jan 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.20.0:
  * Particle class:
  - Deprecated method find method removed. Use findall or
    finditer instead.
  - HTML Greek letters in particle names use hex code rather
    than entity name.
  * PDGID class method and related standalone functions:
    Deprecated function is_composite_quark_or_lepton removed. Use
    is_excited_quark_or_lepton instead.
  * Documentation: README updated with info on the new
    experiment-specific module particle.lhcb.
  * Miscellaneous:
  - Support for Python 2 and Python 3.5 dropped.
  - Full static typing implemented.
- Update tests.tar.xz tarball to version 0.20.0.
- New BuildRequires: python-pytest-benchmark.
* Sat Sep 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.16.1:
  * Fixed a regression with the import time being unreasonably
    slow.
  * Restore Python 3.5 support (no benefit to drop until 2.7 is
    dropped).
- Changes from version 0.16.0:
  * Particle class:
  - Added finditer, which returns an iterator instead of a
    complete list like findall.
  - Method find deprecated. It will be removed from version
    0.17.0 onwards.
  * PDGID class:
  - New functions is_sm_lepton, is_sm_quark and
    is_excited_quark_or_lepton for qualification of PDG IDs.
  - is_composite_quark_or_lepton deprecated in favour of better
    named is_excited_quark_or_lepton.
  - is_lepton fixed to match the behaviour of the related
    is_quark, i.e. now excited leptons are not considered
    leptons (only SM and 4th generation leptons).
  - Improvements to documentation.
  - Test suite enhanced accordingly.
  * Data files:
  - Added the 2021 PDG data table .mcd file, now default.
  - Version 10 of package CSV data files: Since PDG 2021
    information now the default.
  - Lifetimes of neutrinos set to infinity.
  - Check added for duplicate entries in .mcd PDG data files.
  * Tests:
  - Tests of coverage added back, using Codecov on GHAs.
  - CI enhanced, e.g. adding codespell, isort and flake8 checks
    tp pre-commit hooks.
  * Miscellaneous:
  - Support for Python 3.10 added.
  - Several FutureWarning warnings fixed.
  - Code modernisation.
- Update _service file for new tests.
- New BuildRequires for tests: python-Deprecated.
* Sat Jul  3 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.15.1:
  * Bug fix in Particle.to_dict.
  * Code improvements thanks to Sourcery.
  * Clean-up of unnecessary files/code.
- Update tests tarball to version 0.15.1 too.
* Sun May 23 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.15.0:
  * Particle class:
  - Literals now defined for all particles in the loaded
    "database" CSV file, excluding nuclei.
  - Defined and/or fixed the programmatic names for diquarks and
    SUSY particles.
  * Data CSV files:
  - Version 9 of package data files, with all antiparticle bars
    done with \overline instead of \bar.
  * Miscellaneous:
  - Added latex_name_unicode() function to convert in particle
    names in LaTeX all greek letters by their unicode.
  - Added a .zenodo.json file to provide enhanced metadata for
    Zenodo.
* Sat May  8 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.14.1:
  * No user visible changes.
* Thu Jan 21 2021 andy great <andythe_great@pm.me>
- Make importlib_resources dependency available to all opensuse
  version.
* Sun Nov 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.14.0:
  * Particle class: Methods `Particle.to_list` and
    `Particle.to_dict` enhanced.
  * Data CSV files:
  - Version 8 of package data files, with fixed parities for
    antibaryons with undefined parity.
  - Tests added to check if every particle is parsed and loaded
    correctly.
  * Miscellaneous: - Minor fix on static typing.
- Update _service file to download tests at tag 0.14.0.
* Mon Nov 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add _service file to:
  * Download tests dir from upstream git repository.
  * Recompress downloaded tests.tar into tests.tar.xz.
- Update %%prep section to unpack tests tarball into main source
  dir.
- Add BuildRequires: python-importlib_resources for openSUSE <=
  1500; needed for tests.
- Implement %%check section where pytest runs the tests.
* Fri Nov 13 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.13.1:
  * PDG ID: Minor simplifications in some PID functions.
  * Particle class: Test for Particle.is_unflavoured_meson added.
  * Miscellaneous: Full static typing implemented.
* Sat Oct 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.13.0:
  * Dependencies: hepunits >= 2.0.0.
  * Tests:
  * CI updates.
  * Tests adapted to hepunits 2.0.0.
  * Miscellaneous:
  * Support for Python 3.9 added.
- Drop commands to rename the egg-info dir in keeping with the
  proper version for openSUSE Leap; the version is now
  automatically correctly determined.
* Wed Aug  5 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
